@@ -303,9 +303,9 @@ static MagickBooleanType ReadHEICImageByID(const ImageInfo *image_info,
   /*
     Set image size.
   */
-  image->depth=8;
   image->columns=(size_t) heif_image_handle_get_width(image_handle);
   image->rows=(size_t) heif_image_handle_get_height(image_handle);
+  image->depth=(size_t) heif_image_handle_get_luma_bits_per_pixel(image_handle);
   if (heif_image_handle_has_alpha_channel(image_handle))
     image->alpha_trait=BlendPixelTrait;
   preserve_orientation=IsStringTrue(GetImageOption(image_info,
